@@ -32,9 +32,6 @@ OC.L10N.register(
     "Client apps" : "Klient apps",
     "Bookmarklet" : "Bookmarklet",
     "Add to {instanceName}" : "Tilføj til {instanceName}",
-    "Clear data" : "Fjern data",
-    "Delete all bookmarks" : "Slet alle bogmærker",
-    "Do you really want to delete all your bookmarks?" : "Ønsker du virkelig at slette alle dine bogmærker?",
     "Title" : "Titel",
     "Link" : "Link",
     "Tags" : "Mærker",
