@@ -35,9 +35,6 @@ OC.L10N.register(
     "Also check out the collection of client apps that integrate with this app: " : "Ankaŭ vidu la programojn, kiuj uzas tiun aplikaĵon:",
     "Bookmarklet" : "Legosignilo",
     "Add to {instanceName}" : "Aldoni al {instanceName}",
-    "Clear data" : "Forviŝi datumojn",
-    "Delete all bookmarks" : "Forigi ĉiujn legosignojn",
-    "Do you really want to delete all your bookmarks?" : "Ĉu vi ja volas forigi ĉiujn viaj legosignoj?",
     "Title" : "Titolo",
     "Link" : "Ligilo",
     "Tags" : "Etikedoj",
