@@ -78,10 +78,6 @@ OC.L10N.register(
     "Install on home screen" : "התקנה על מסך הבית",
     "Bookmarklet" : "יישומון סימנייה",
     "Add to {instanceName}" : "הוספה אל {instanceName}",
-    "Clear data" : "ניקוי מידע",
-    "Permanently remove all bookmarks from your account." : "הסרת כל הסימניות מהחשבון שלך לצמיתות.",
-    "Delete all bookmarks" : "מחיקת כל הסימניות",
-    "Do you really want to delete all your bookmarks?" : "למחוק את כל הסימניות שלך?",
     "Please select \"Add to home screen\" in your browser menu" : "נא לבחור באפשרות „הוספה למסך הבית” בתפריט הדפדפן שלך",
     "Title" : "תפקיד",
     "Link" : "קישור",
